@@ -29,6 +29,7 @@ typedef struct _FlatpakInstallation FlatpakInstallation;
 
 #include <gio/gio.h>
 #include <flatpak-installed-ref.h>
+#include <flatpak-instance.h>
 #include <flatpak-remote.h>
 
 #define FLATPAK_TYPE_INSTALLATION flatpak_installation_get_type ()
@@ -52,6 +53,11 @@ typedef struct
  * @FLATPAK_UPDATE_FLAGS_NONE: Fetch remote builds and install the latest one (default)
  * @FLATPAK_UPDATE_FLAGS_NO_DEPLOY: Don't install any new builds that might be fetched
  * @FLATPAK_UPDATE_FLAGS_NO_PULL: Don't try to fetch new builds from the remote repo
+ * @FLATPAK_UPDATE_FLAGS_NO_STATIC_DELTAS: Don't use static deltas when pulling
+ * @FLATPAK_UPDATE_FLAGS_NO_PRUNE: Don't prune the local OSTree repository after updating (Since: 0.11.8)
+ * @FLATPAK_UPDATE_FLAGS_NO_TRIGGERS: Don't call triggers after updating. If used,
+ * the caller must later call flatpak_installation_run_triggers() to update
+ * the exported files. (Since: 1.0.3)
  *
  * Flags to alter the behavior of flatpak_installation_update().
  */
@@ -60,11 +66,19 @@ typedef enum {
   FLATPAK_UPDATE_FLAGS_NO_DEPLOY        = (1 << 0),
   FLATPAK_UPDATE_FLAGS_NO_PULL          = (1 << 1),
   FLATPAK_UPDATE_FLAGS_NO_STATIC_DELTAS = (1 << 2),
+  FLATPAK_UPDATE_FLAGS_NO_PRUNE         = (1 << 3),
+  FLATPAK_UPDATE_FLAGS_NO_TRIGGERS      = (1 << 4),
 } FlatpakUpdateFlags;
 
 /**
  * FlatpakInstallFlags:
  * @FLATPAK_INSTALL_FLAGS_NONE: Default
+ * @FLATPAK_INSTALL_FLAGS_NO_STATIC_DELTAS: Don't use static deltas when pulling
+ * @FLATPAK_INSTALL_FLAGS_NO_DEPLOY: Don't install any new builds that might be fetched
+ * @FLATPAK_INSTALL_FLAGS_NO_PULL: Don't try to fetch new builds from the remote repo
+ * @FLATPAK_INSTALL_FLAGS_NO_TRIGGERS: Don't call triggers after installing. If used,
+ * the caller must later call flatpak_installation_run_triggers() to update
+ * the exported files. (Since: 1.0.3)
  *
  * Flags to alter the behavior of flatpak_installation_install_full().
  */
@@ -73,8 +87,56 @@ typedef enum {
   FLATPAK_INSTALL_FLAGS_NO_STATIC_DELTAS = (1 << 0),
   FLATPAK_INSTALL_FLAGS_NO_DEPLOY        = (1 << 2),
   FLATPAK_INSTALL_FLAGS_NO_PULL          = (1 << 3),
+  FLATPAK_INSTALL_FLAGS_NO_TRIGGERS      = (1 << 4),
 } FlatpakInstallFlags;
 
+/**
+ * FlatpakUninstallFlags:
+ * @FLATPAK_UNINSTALL_FLAGS_NONE: Default
+ * @FLATPAK_UNINSTALL_FLAGS_NO_PRUNE: Don't prune the local OSTree repository after uninstalling
+ * @FLATPAK_UNINSTALL_FLAGS_NO_TRIGGERS: Don't call triggers after uninstalling. If used,
+ * the caller must later call flatpak_installation_run_triggers() to update
+ * the exported file. (Since: 1.0.3)
+ *
+ * Flags to alter the behavior of flatpak_installation_uninstall_full().
+ *
+ * Since: 0.11.8
+ */
+typedef enum {
+  FLATPAK_UNINSTALL_FLAGS_NONE            = 0,
+  FLATPAK_UNINSTALL_FLAGS_NO_PRUNE        = (1 << 0),
+  FLATPAK_UNINSTALL_FLAGS_NO_TRIGGERS     = (1 << 1),
+} FlatpakUninstallFlags;
+
+/**
+ * FlatpakLaunchFlags:
+ * @FLATPAK_LAUNCH_FLAGS_NONE: Default
+ * @FLATPAK_LAUNCH_FLAGS_DO_NOT_REAP: Do not reap the child. Use this if you want to wait
+ * for the child with g_child_watch_add(). (Snce: 1.1)
+ *
+ * Flags to alter the behavior of flatpak_installation_launch_full().
+ */
+typedef enum {
+  FLATPAK_LAUNCH_FLAGS_NONE        = 0,
+  FLATPAK_LAUNCH_FLAGS_DO_NOT_REAP = (1 << 0),
+} FlatpakLaunchFlags;
+
+/**
+ * FlatpakQueryFlags:
+ * @FLATPAK_QUERY_FLAGS_NONE: Default
+ * @FLATPAK_QUERY_FLAGS_ONLY_CACHED: Don't do any network i/o, but only return cached data.
+ * This can return stale data, or a #FLATPAK_ERROR_NOT_CACHED error, however it is a
+ * lot more efficient if you're doing many requests.
+ *
+ * Flags to alter the behavior of e.g flatpak_installation_list_remote_refs_full().
+ *
+ * Since: 1.3.3
+ */
+typedef enum {
+  FLATPAK_QUERY_FLAGS_NONE        = 0,
+  FLATPAK_QUERY_FLAGS_ONLY_CACHED = (1 << 0),
+} FlatpakQueryFlags;
+
 /**
  * FlatpakStorageType:
  * @FLATPAK_STORAGE_TYPE_DEFAULT: default
@@ -117,6 +179,9 @@ FLATPAK_EXTERN FlatpakInstallation *flatpak_installation_new_for_path (GFile
                                                                        gboolean      user,
                                                                        GCancellable *cancellable,
                                                                        GError      **error);
+FLATPAK_EXTERN void flatpak_installation_set_no_interaction (FlatpakInstallation *self,
+                                                             gboolean             no_interaction);
+FLATPAK_EXTERN gboolean flatpak_installation_get_no_interaction (FlatpakInstallation *installation);
 
 /**
  * FlatpakProgressCallback:
@@ -152,6 +217,15 @@ FLATPAK_EXTERN gboolean             flatpak_installation_launch (FlatpakInstalla
                                                                  const char          *commit,
                                                                  GCancellable        *cancellable,
                                                                  GError             **error);
+FLATPAK_EXTERN gboolean             flatpak_installation_launch_full (FlatpakInstallation *self,
+                                                                      FlatpakLaunchFlags   flags,
+                                                                      const char          *name,
+                                                                      const char          *arch,
+                                                                      const char          *branch,
+                                                                      const char          *commit,
+                                                                      FlatpakInstance    **instance_out,
+                                                                      GCancellable        *cancellable,
+                                                                      GError             **error);
 FLATPAK_EXTERN GFileMonitor        *flatpak_installation_create_monitor (FlatpakInstallation *self,
                                                                          GCancellable        *cancellable,
                                                                          GError             **error);
@@ -165,6 +239,10 @@ FLATPAK_EXTERN GPtrArray           *flatpak_installation_list_installed_refs_by_
 FLATPAK_EXTERN GPtrArray           *flatpak_installation_list_installed_refs_for_update (FlatpakInstallation *self,
                                                                                          GCancellable        *cancellable,
                                                                                          GError             **error);
+FLATPAK_EXTERN GPtrArray           *flatpak_installation_list_unused_refs (FlatpakInstallation *self,
+                                                                           const char          *arch,
+                                                                           GCancellable        *cancellable,
+                                                                           GError             **error);
 FLATPAK_EXTERN FlatpakInstalledRef * flatpak_installation_get_installed_ref (FlatpakInstallation *self,
                                                                              FlatpakRefKind       kind,
                                                                              const char          *name,
@@ -180,11 +258,11 @@ FLATPAK_EXTERN FlatpakInstalledRef * flatpak_installation_get_current_installed_
 FLATPAK_EXTERN GPtrArray           *flatpak_installation_list_remotes (FlatpakInstallation *self,
                                                                        GCancellable        *cancellable,
                                                                        GError             **error);
-FLATPAK_EXTERN GPtrArray           *flatpak_installation_list_remotes_by_type (FlatpakInstallation     *self,
-                                                                               const FlatpakRemoteType  types[],
-                                                                               gsize                    num_types,
-                                                                               GCancellable            *cancellable,
-                                                                               GError                 **error);
+FLATPAK_EXTERN GPtrArray           *flatpak_installation_list_remotes_by_type (FlatpakInstallation    *self,
+                                                                               const FlatpakRemoteType types[],
+                                                                               gsize                   num_types,
+                                                                               GCancellable           *cancellable,
+                                                                               GError                **error);
 FLATPAK_EXTERN FlatpakRemote        *flatpak_installation_get_remote_by_name (FlatpakInstallation *self,
                                                                               const gchar         *name,
                                                                               GCancellable        *cancellable,
@@ -202,14 +280,17 @@ FLATPAK_EXTERN gboolean              flatpak_installation_update_remote_sync (Fl
                                                                               GCancellable        *cancellable,
                                                                               GError             **error);
 FLATPAK_EXTERN gboolean              flatpak_installation_set_config_sync (FlatpakInstallation *self,
-									   const char          *key,
-									   const char          *value,
-									   GCancellable        *cancellable,
-									   GError             **error);
-FLATPAK_EXTERN char *                flatpak_installation_get_config      (FlatpakInstallation *self,
-									   const char          *key,
-									   GCancellable        *cancellable,
-									   GError             **error);
+                                                                           const char          *key,
+                                                                           const char          *value,
+                                                                           GCancellable        *cancellable,
+                                                                           GError             **error);
+FLATPAK_EXTERN gboolean              flatpak_installation_get_min_free_space_bytes (FlatpakInstallation *self,
+                                                                                    guint64             *out_bytes,
+                                                                                    GError             **error);
+FLATPAK_EXTERN char *                flatpak_installation_get_config (FlatpakInstallation *self,
+                                                                      const char          *key,
+                                                                      GCancellable        *cancellable,
+                                                                      GError             **error);
 FLATPAK_EXTERN char *              flatpak_installation_load_app_overrides (FlatpakInstallation *self,
                                                                             const char          *app_id,
                                                                             GCancellable        *cancellable,
@@ -277,6 +358,17 @@ FLATPAK_EXTERN gboolean             flatpak_installation_uninstall (FlatpakInsta
                                                                     GCancellable           *cancellable,
                                                                     GError                **error);
 
+FLATPAK_EXTERN gboolean             flatpak_installation_uninstall_full (FlatpakInstallation    *self,
+                                                                         FlatpakUninstallFlags   flags,
+                                                                         FlatpakRefKind          kind,
+                                                                         const char             *name,
+                                                                         const char             *arch,
+                                                                         const char             *branch,
+                                                                         FlatpakProgressCallback progress,
+                                                                         gpointer                progress_data,
+                                                                         GCancellable           *cancellable,
+                                                                         GError                **error);
+
 FLATPAK_EXTERN gboolean          flatpak_installation_fetch_remote_size_sync (FlatpakInstallation *self,
                                                                               const char          *remote_name,
                                                                               FlatpakRef          *ref,
@@ -293,6 +385,11 @@ FLATPAK_EXTERN GPtrArray    *    flatpak_installation_list_remote_refs_sync (Fla
                                                                              const char          *remote_or_uri,
                                                                              GCancellable        *cancellable,
                                                                              GError             **error);
+FLATPAK_EXTERN GPtrArray    *    flatpak_installation_list_remote_refs_sync_full (FlatpakInstallation *self,
+                                                                                  const char          *remote_or_uri,
+                                                                                  FlatpakQueryFlags    flags,
+                                                                                  GCancellable        *cancellable,
+                                                                                  GError             **error);
 FLATPAK_EXTERN FlatpakRemoteRef  *flatpak_installation_fetch_remote_ref_sync (FlatpakInstallation *self,
                                                                               const char          *remote_name,
                                                                               FlatpakRefKind       kind,
@@ -301,20 +398,29 @@ FLATPAK_EXTERN FlatpakRemoteRef  *flatpak_installation_fetch_remote_ref_sync (Fl
                                                                               const char          *branch,
                                                                               GCancellable        *cancellable,
                                                                               GError             **error);
+FLATPAK_EXTERN FlatpakRemoteRef  *flatpak_installation_fetch_remote_ref_sync_full (FlatpakInstallation *self,
+                                                                                   const char          *remote_name,
+                                                                                   FlatpakRefKind       kind,
+                                                                                   const char          *name,
+                                                                                   const char          *arch,
+                                                                                   const char          *branch,
+                                                                                   FlatpakQueryFlags    flags,
+                                                                                   GCancellable        *cancellable,
+                                                                                   GError             **error);
 FLATPAK_EXTERN gboolean          flatpak_installation_update_appstream_sync (FlatpakInstallation *self,
                                                                              const char          *remote_name,
                                                                              const char          *arch,
                                                                              gboolean            *out_changed,
                                                                              GCancellable        *cancellable,
                                                                              GError             **error);
-FLATPAK_EXTERN gboolean          flatpak_installation_update_appstream_full_sync (FlatpakInstallation *self,
-                                                                                  const char          *remote_name,
-                                                                                  const char          *arch,
+FLATPAK_EXTERN gboolean          flatpak_installation_update_appstream_full_sync (FlatpakInstallation    *self,
+                                                                                  const char             *remote_name,
+                                                                                  const char             *arch,
                                                                                   FlatpakProgressCallback progress,
                                                                                   gpointer                progress_data,
-                                                                                  gboolean            *out_changed,
-                                                                                  GCancellable        *cancellable,
-                                                                                  GError             **error);
+                                                                                  gboolean               *out_changed,
+                                                                                  GCancellable           *cancellable,
+                                                                                  GError                **error);
 FLATPAK_EXTERN GPtrArray    *    flatpak_installation_list_remote_related_refs_sync (FlatpakInstallation *self,
                                                                                      const char          *remote_name,
                                                                                      const char          *ref,
@@ -330,13 +436,16 @@ FLATPAK_EXTERN gboolean          flatpak_installation_remove_local_ref_sync (Fla
                                                                              const char          *remote_name,
                                                                              const char          *ref,
                                                                              GCancellable        *cancellable,
-                                                                             GError              **error);
+                                                                             GError             **error);
 FLATPAK_EXTERN gboolean          flatpak_installation_cleanup_local_refs_sync (FlatpakInstallation *self,
                                                                                GCancellable        *cancellable,
-                                                                               GError              **error);
+                                                                               GError             **error);
 FLATPAK_EXTERN gboolean          flatpak_installation_prune_local_repo (FlatpakInstallation *self,
                                                                         GCancellable        *cancellable,
-                                                                        GError              **error);
+                                                                        GError             **error);
+FLATPAK_EXTERN gboolean          flatpak_installation_run_triggers (FlatpakInstallation *self,
+                                                                    GCancellable        *cancellable,
+                                                                    GError             **error);
 
 
 #endif /* __FLATPAK_INSTALLATION_H__ */
